@@ -514,7 +514,6 @@ typedef struct _export_options {
     bool reposurgeon;
     bool embed_ids;
     bool force_dates;
-    enum {adaptive, fast, canonical} reportmode;
     bool authorlist;
     bool progress;
 } export_options_t;
@@ -725,7 +724,7 @@ extern unsigned int natoms;
  * Global options
  */
 
-extern bool nowarn;
+extern bool nowarn, noignores;
 extern int commit_time_window;
 extern bool trust_commitids;
 extern FILE *LOGFILE;
