@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.3.2.  */
+/* A Bison parser, made by GNU Bison 3.5.1.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -88,10 +88,9 @@ extern int yydebug;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-
 union YYSTYPE
 {
-#line 31 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1921  */
+#line 31 "/home/esr/public_html/cvs-fast-export//gram.y"
 
     int		i;
     cvstime_t	date;
@@ -107,9 +106,9 @@ union YYSTYPE
     cvs_branch	*branch;
     cvs_file	*file;
 
-#line 111 "gram.h" /* yacc.c:1921  */
-};
+#line 110 "gram.h"
 
+};
 typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
